WWDropdown class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- WWDropdown
Constructors
-
WWDropdown({Key? key, double elevation = 2, bool isSingleSelect = false, required WWDropdownApi api, TextStyle? itemTextStyle, Decoration? decoration, TextStyle? hintStyle, TextStyle? style, EdgeInsetsGeometry? padding, required WWDropDownItemSelect onSelect, InputDecoration? searchDecoration, int apiLimitCount = 10, String? hintText, double maxPopViewHeight = 200, required WWDropdownItem<
Object> ? selectedItem, ShapeBorder? popUpShape}) -
const
Properties
- api → WWDropdownApi
-
final
- apiLimitCount → int
-
final
- decoration → Decoration?
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
final
- hintText → String?
-
final
- isSingleSelect → bool
-
final
- itemTextStyle → TextStyle?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxPopViewHeight → double
-
final
- onSelect → WWDropDownItemSelect
-
final
- padding → EdgeInsetsGeometry?
-
final
- popUpShape → ShapeBorder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchDecoration → InputDecoration?
-
final
-
selectedItem
→ WWDropdownItem<
Object> ? -
final
- style → TextStyle?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< WWDropdown> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited